# Cloud

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **int** |  | [optional] [readonly] 
**name** | **str** | Name of the cloud | 
**features** | [**list[Feature]**](Feature.md) |  | [optional] [readonly] 
**marketplace_apps** | [**list[MarketplaceApp]**](MarketplaceApp.md) |  | [optional] [readonly] 
**organization** | [**Organization**](Organization.md) |  | [optional] 
**organization_id** | **int** |  | [optional] 
**creator** | [**User**](User.md) |  | [optional] 
**creator_app** | **str** |  | [optional] [readonly] 
**is_default** | **bool** |  | [optional] [readonly] 
**created_at** | **datetime** | Creation date | [optional] [readonly] 
**image** | **str** |  | [optional] [readonly] 
**updated_at** | **datetime** | Date of the last update | [optional] [readonly] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


